#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.3.0.0
visibility:           public
id:                   hls-test-utils-2.3.0.0-8bjR9NKUGdL4rMpJa7Ki7s
key:                  hls-test-utils-2.3.0.0-8bjR9NKUGdL4rMpJa7Ki7s
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4285054adc001100caed0c551f545aa2
exposed:              True
exposed-modules:      Test.Hls Test.Hls.FileSystem Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.3.0.0-8bjR9NKUGdL4rMpJa7Ki7s
depends:
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    async-2.2.6-ITRC11Ox8a3Q3zDt3UwKf base-4.18.2.1
    blaze-markup-0.8.3.0-BwtxwotQvqT6MBMEaH67IA bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF
    filepath-1.4.300.1 ghcide-2.3.0.0-Fl8012fesfY8JAHd1DYtXK
    hls-graph-2.3.0.0-J4ReKBiXKa6ELhqG4l0L5h
    hls-plugin-api-2.3.0.0-CqqJ1DVds9n4biAp5UxsaC
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
    lsp-test-0.16.0.0-GLEQBIRu0d06rJkfRSk8nf
    lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4
    row-types-1.0.1.2-DPodS6wEnzgipmVs1yqhU
    tasty-1.5.4-HqPE37sg7IfLt8RoOq2iQG
    tasty-expected-failure-0.12.3-BRL3HgLjyKxLS02asIRxos
    tasty-golden-2.3.6-LikgaHUk8HPCxpmcuDgshg
    tasty-hunit-0.10.2-6fX4OyMSfRBCGgqssqVmfn
    tasty-rerun-1.1.20-18eE9yVbrkQ8CgD5G9P52D
    temporary-1.3-6srFELH6ZJ85EWwSBp1olQ text-2.0.2
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

